@@ -1,7 +1,7 @@
 /*
  *  list.h
  * 
- *  Copyright (c) 2002 by Judd Vinet <jvinet@zeroflux.org>
+ *  Copyright (c) 2002-2004 by Judd Vinet <jvinet@zeroflux.org>
  * 
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,6 +30,11 @@ typedef struct __pmlist_t {
 	struct __pmlist_t* next;
 } PMList;
 
+
+/*  Sort comparison callback function declaration.  */
+typedef int (*cmp_fn) (const void *, const void *);
+
+
 PMList* list_new();
 void list_free(PMList* list);
 PMList* list_add(PMList* list, void* data);
@@ -42,6 +47,8 @@ int list_strcmp(const void *s1, const void *s2);
 PMList *list_sort(PMList *list);
 void list_display(const char *title, PMList *list);
 
+PMList* list_add_sorted(PMList *list, void *data, cmp_fn sortfunc);
+
 #endif
 
 /* vim: set ts=2 sw=2 noet: */
